[![Build Status](https://travis-ci.org/uw-it-cte/uw-restclients-wheniwork.svg?branch=master)](https://travis-ci.org/uw-it-cte/uw-restclients-wheniwork)
[![Coverage Status](https://coveralls.io/repos/github/uw-it-cte/uw-restclients-wheniwork/badge.svg)](https://coveralls.io/github/uw-it-cte/uw-restclients-wheniwork)

# uw-restclients-wheniwork

Python client for the WhenIWork REST API. http://dev.wheniwork.com/
